myorth(X) makes an orthonormal basis for the space spanned by the
columns of X. The number of columns returned equals myrank(X),
which is the rank of X.
myorth(X, tol_ = 1e-09)numeric matrix.
tuning parameter for the rank.
myorth returns a matrix, whose columns form an orthonormal
basis.
myrank returns a single number, which is the rank of X.
The calculations are based on the singular value decomposition
(svd). And myrank(X) is the number of singular values
of X that are larger than max(dim(X))*svd(x)$d[1]*tol_.