The function takes the output from modelData as input and calculates
adjusted data
orth_D(D, model, method)A list containing a regressor matrix for each model term
The model coded as a matrix
Either "test" or "om"
An adjusted version of D is returned.
The "test" method adjusts data according to Type II* sums of squares.
This is an extension of the traditional Type II method. The "om"
method orthogonalises terms according to the model hierarchy. The result is
a non-overparameterised representation of the model.