Print method for objects of class "ffmanova". It prints an ANOVA
table.
# S3 method for ffmanova
print(x, digits = max(getOption("digits") - 3, 3), ...)"ffmanova" object. Typically created by
ffmanova.
positive integer. Minimum number of significant digits to be used for printing most numbers.
further arguments sent to the underlying
printCoefmat.
Invisibly returns the original object.
The function constructs an anova table, and prints it using
printCoefmat with tailored arguments.